DieselReserveSpecialization

Trait DieselReserveSpecialization 

pub trait DieselReserveSpecialization { }
Available on crate feature i-implement-a-third-party-backend-and-opt-into-breaking-changes only.
This is a marker trait which indicates that diesel may specialize a certain QueryFragment impl in a later version. If you as a user encounter, where rustc suggests adding this a bound to a type implementing Backend consider adding the following bound instead YourQueryType: QueryFragment<DB> (the concrete bound is likely mentioned by rustc as part of a note: …)

For any user implementing a custom backend: You likely want to implement this trait for your custom backend type to opt in the existing QueryFragment impls in diesel. As indicated by the i-implement-a-third-party-backend-and-opt-into-breaking-changes feature diesel reserves the right to specialize any generic QueryFragment impl via SqlDialect in a later minor version release

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl DieselReserveSpecialization for Mysql

Available on crate feature mysql_backend only.
Source

impl DieselReserveSpecialization for Pg

Available on crate feature postgres_backend only.
Source

impl DieselReserveSpecialization for Sqlite

Available on crate feature __sqlite-shared only.